\name{annotator}
\alias{General_Inquirer_Category_Annotator}
\title{General Inquirer category annotators}
\description{
  Generate an annotator which computes General Inquirer tag category
  annotations for the word token lemmas in the given annotations.
}
\usage{
General_Inquirer_Category_Annotator(Categories = NULL, Source = NULL, 
                                    which = c("all", "first"),
                                    pos = FALSE, map = NULL)
}
\arguments{
  \item{Categories}{a character vector giving a subset of the General
    Inquirer tag categories to use for the annotation, or \code{NULL}
    (default) corresponding to using all tag categories.}
  \item{Source}{a character vector giving the General Inquirer entry
    sources to use for the annotations (possible values: \code{"H4"},
    \code{"H4Lvd"} and \code{"Lvd"}), or \code{NULL} (default),
    corresponding to using all sources.}
  \item{which}{a character string indicating how to handle situations
    when a lemma occurs in several General Inquirer entries:
    \code{"all"} indicates using the categories for all entries,
    \code{"first"} the categories of the first entry.
  }
  \item{pos}{a logical indicating whether to use available POS tags
    suitably mapped to General Inquirer marker categories for looking up
    lemmas in the General Inquirer table.  See below for details.
  }
  \item{map}{a named list giving the mapping of POS tags to marker
    categories.  See below for details.  Only used if \code{pos} is
    true.
  }
}
\value{
  An \code{\link[NLP]{Annotator}} object giving the created General
  Inquirer category annotator.
}
\details{
  Mapping POS tags to General Inquirer marker categories is not
  straightforward, and controllable via the \code{map} argument.  This
  should be a named list with elements giving POS tags used in the
  annotation and corresponding names the marker categories these should
  be mapped to.  By default, a simple map of Penn Treebank POS tags to
  syntactic General Inquirer marker categories is used, which maps verb
  POS tags to the \code{SUPV} verb and noun POS tags to the \code{NOUN}
  marker categories.  POS tags not mapped explicitly are gathered in a
  \dQuote{nomatch} category.

  When \code{pos} is true, the General Inquirer entries used are grouped
  according the the target marker categories, and again processed using
  the \code{which} argument.  The annotation then disambiguates lemmas
  according to the target marker categories mapped from the POS tags.

  The annotator needs the lemmas as the \code{lemma} feature of the
  \code{\link[NLP]{Annotation}} object it is called on; if \code{pos} is
  true, it also needs the POS tags as the \code{POS} feature.

  The annotator returns an annotation object with the word tokens for
  which it found suitable tag categories in the General Inquirer tables,
  with these categories as the \code{GI_category} feature of the
  annotation object.
}
\examples{
require("NLP")
s <- String("I love statistical computing.")
##           ****5****0****5****0****5****
a <- c(Annotation(1, "sentence", 1, 29),
       Annotation(2, "word",  1,  1,
                  list(list(POS = "PRP", lemma = "I"))),
       Annotation(3, "word",  3,  6,
                  list(list(POS = "VBP", lemma = "love"))),
       Annotation(4, "word",  8, 18,
                  list(list(POS = "JJ",  lemma = "statistical"))),
       Annotation(5, "word", 20, 28,
                  list(list(POS = "NN",  lemma = "computing"))))

f <- General_Inquirer_Category_Annotator()
y <- f(s, a)
y
y$features

f <- General_Inquirer_Category_Annotator(which = "first")
y <- f(s, a)
y
y$features
}
