\name{general_inquirer}
\alias{General_Inquirer_categories}
\title{General Inquirer Category Listings}
\description{
  A lexicon-like table with the General Inquirer tag and marker
  categories.
}
\usage{
General_Inquirer_categories
}
\format{
  A data frame with the following elements/variables.
  \describe{
    \item{Entry}{a character vector with the entry words or word senses}
    \item{Lemma}{a character vector with the corresponding lemma}
    \item{Source}{a character vector with the source of the entries}
    \item{Categories}{a list of character vectors with the tag
      categories for the entries}
    \item{OthTags}{a list of character vectors with the marker
      categories for the entries}
    \item{Defined}{a character vector with additional information about
      the entries}
  }
  (The naming closely follows that used for the GI spreadsheet.)
}
\details{
  The General Inquirer (GI) proves tag categories from three sources
  (the Harvard IV-4 dictionary (H4), the Lasswell value dictionary
  (LVD), and several categories additionally constructed) and
  \dQuote{marker} categories \dQuote{primarily developed as a resource
    for disambiguation, but also available to users}.

  The category listings from the GI are said to be appropriate for
  \dQuote{\emph{developing scoring procedures that enlist multiple
      categories and analyze the tag patterns assigned to each
      sentence.  This tag assignment pattern across sentences could then
      be used to generate an overall assessment of a document.}}
  However, note that tagging with GI simply maps text according to
  categories and does not necessarily identify meaning. Nevertheless,
  these mappings may provide useful information about a wide variety of
  texts.

  According to the information on GI's website each entry in a category
  is given equal weight. This decision of the category developers is
  partly based on the fact that it is difficult to obtain agreement
  about the optimal weights and that if such weights exists would they
  really contribute to the score's general validity.
}
\source{
  General Inquirer Basic Spreadsheet Version 1.02 (tab-delimited
  format).
}
\references{
  General Inquirer Home Page.
  \url{http://www.wjh.harvard.edu/~inquirer/}

  General Inquirer Basic Spreadsheet.
  \url{http://www.wjh.harvard.edu/~inquirer/spreadsheet_guide.htm}
}
\seealso{
  \url{http://www.wjh.harvard.edu/~inquirer/homecat.htm} for more
  information about the 182 tag categories.
  
  \code{\link{Kelly_Stone_syntactic_markers}} and
  \code{\link{Kelly_Stone_semantic_markers}} for more information about
  the marker categories.
}
\examples{
## All entries for lemma 'say':
subset(General_Inquirer_categories, Lemma == "say")

## Entries in category 'Positiv':
contains <- function(table, x) !is.na(match(x, table))
tab <- subset(General_Inquirer_categories,
             sapply(Categories, contains, "Positiv"))
head(tab)
}
\keyword{datasets}
